@@ -33,7 +33,7 @@ class AlarmListView : public EventListView
         Q_OBJECT
     public:
         explicit AlarmListView(const QByteArray& configGroup, QWidget* parent = nullptr);
-        void        setModel(QAbstractItemModel*) Q_DECL_OVERRIDE;
+        void        setModel(QAbstractItemModel*) override;
         void        selectTimeColumns(bool time, bool timeTo);
 
     private Q_SLOTS:
